##  Filter, Sort, and Search Surveys
The KPI cards at the top show the number of surveys in various statuses, such as total, live, draft, finished, and surveys with safety net issues. These cards also function as quick filters. For instance, clicking the Live card lists surveys that are currently live and running. Clicking the Total card removes all filters, listing all surveys.
![Managing Surveys](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a30587a44101492cfe37ca49a8897_LowRes.png)
Managing Surveys
The list provides details about the user who shared the survey, the progress percentage, the status of the survey run (Live/Draft/Finished), and the user who created the survey form. You can sort the list by title and the status of the survey. Additionally, you can search for a specific survey using the search bar at the top.
